==> kipi-plugins_20.04.3.orig.tar.xz: kipi-plugins-20.04.3/facebook/kipiplugin_facebook.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Facebook Export
Name=Facebook Export
Name[ca]=Exportador al Facebook
Name[ca@valencia]=Exportador al Facebook
Name[cs]=Export do Facebooku
Name[da]=Eksport til Facebook
Name[de]=Facebook-Export
Name[el]=Εξαγωγή στο Facebook
Name[en_GB]=Facebook Export
Name[es]=Exportar a Facebook
Name[et]=Facebooki eksport
Name[eu]=Facebook-era esportatzea
Name[fi]=Facebook-vienti
Name[fr]=Export vers Facebook
Name[gl]=Exportación de Facebook
Name[id]=Facebook Export
Name[is]=Facebook útflutningur
Name[it]=Esportazione a Facebook
Name[ko]=Facebook 내보내기
Name[nl]=Facebook-export
Name[nn]=Facebook-eksport
Name[pl]=Eksport do Facebooka
Name[pt]=Exportação para o Facebook
Name[pt_BR]=Exportação para o Facebook
Name[ru]=Экспорт в Facebook
Name[sk]=Facebook Export
Name[sl]=Izvoz v Facebook
Name[sv]=Facebook export
Name[tr]=Facebook Dışa Aktar
Name[uk]=Експорт до Facebook
Name[x-test]=xxFacebook Exportxx
Name[zh_CN]=Facebook 导出
Name[zh_TW]=Facebook 匯出
Comment=A tool to export images to a remote Facebook web service
Comment[ca]=Una eina per exportar les imatges a un servei web remot Facebook
Comment[ca@valencia]=Una eina per exportar les imatges a un servei web remot Facebook
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Facebook
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Facebook-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zum Facebook-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού Facebook
Comment[en_GB]=A tool to export images to a remote Facebook web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Facebook
Comment[et]=Tööriist piltide eksportimiseks Facebooki veebiteenusesse
Comment[eu]=Irudiak urruneko Facebook web zerbitzu batera esportatzeko tresna bat
Comment[fi]=Työkalu kuvien viemiseksi Facebook-etäverkkopalveluun
Comment[fr]=Outil pour exporter des images vers le service en ligne Facebook
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Facebook remoto
Comment[id]=Sebuah alat untuk mengekspor citra ke layanan web Facebook jarak jauh
Comment[is]=Verkfæri til að flytja inn myndir frá fjartengdri Facebook vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio web remoto Facebook
Comment[ko]=원격 Facebook 웹 서비스로 이미지를 내보내는 도구
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Facebook-webservice te exporteren
Comment[nn]=Verktøy for eksport av bilete til Facebook-tenesta på nettet
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Facebooka
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Facebook
Comment[pt_BR]=Ferramenta para exportar imagens para o Facebook
Comment[ru]=Инструмент для экспорта в социальную сеть Facebook
Comment[sk]=Nástroj na export obrázkov do vzdialenej webovej služby Facebook
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Facebook
Comment[sv]=Ett verktyg för att exportera bilder till en Facebook webbtjänst
Comment[tr]=Resimleri uzak bir Facebook web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень до віддаленої служби Facebook
Comment[x-test]=xxA tool to export images to a remote Facebook web servicexx
Comment[zh_CN]=一个将图像导出到远程 Facebook 网络服务的工具
Comment[zh_TW]=匯出圖片到遠端 Facebook 網路服務的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_facebook
Icon=kipi-facebook
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Luka Renko, lure at kubuntu dot org

==> kipi-plugins-20.12.1.tar.xz: kipi-plugins-20.12.1/facebook/kipiplugin_facebook.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Facebook Export
Name=Facebook Export
Name[ca]=Exportador al Facebook
Name[ca@valencia]=Exportador al Facebook
Name[cs]=Export do Facebooku
Name[da]=Eksport til Facebook
Name[de]=Facebook-Export
Name[el]=Εξαγωγή στο Facebook
Name[en_GB]=Facebook Export
Name[es]=Exportar a Facebook
Name[et]=Facebooki eksport
Name[eu]=Facebook-era esportatzea
Name[fi]=Facebook-vienti
Name[fr]=Export vers Facebook
Name[gl]=Exportación de Facebook
Name[id]=Facebook Export
Name[is]=Facebook útflutningur
Name[it]=Esportazione a Facebook
Name[ko]=Facebook 내보내기
Name[nl]=Facebook-export
Name[nn]=Facebook-eksport
Name[pl]=Eksport do Facebooka
Name[pt]=Exportação para o Facebook
Name[pt_BR]=Exportação para o Facebook
Name[ru]=Экспорт в Facebook
Name[sk]=Facebook Export
Name[sl]=Izvoz v Facebook
Name[sv]=Facebook export
Name[tr]=Facebook Dışa Aktar
Name[uk]=Експорт до Facebook
Name[x-test]=xxFacebook Exportxx
Name[zh_CN]=Facebook 导出
Name[zh_TW]=Facebook 匯出
Comment=A tool to export images to a remote Facebook web service
Comment[ca]=Una eina per a exportar les imatges a un servei web remot Facebook
Comment[ca@valencia]=Una eina per a exportar les imatges a un servei web remot Facebook
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Facebook
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Facebook-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zum Facebook-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού Facebook
Comment[en_GB]=A tool to export images to a remote Facebook web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Facebook
Comment[et]=Tööriist piltide eksportimiseks Facebooki veebiteenusesse
Comment[eu]=Irudiak urruneko Facebook web zerbitzu batera esportatzeko tresna bat
Comment[fi]=Työkalu kuvien viemiseksi Facebook-etäverkkopalveluun
Comment[fr]=Outil pour exporter des images vers le service en ligne Facebook
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Facebook remoto
Comment[id]=Sebuah alat untuk mengekspor citra ke layanan web Facebook jarak jauh
Comment[is]=Verkfæri til að flytja inn myndir frá fjartengdri Facebook vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio web remoto Facebook
Comment[ko]=원격 Facebook 웹 서비스로 이미지를 내보내는 도구
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Facebook-webservice te exporteren
Comment[nn]=Verktøy for eksport av bilete til Facebook-tenesta på nettet
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Facebooka
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Facebook
Comment[pt_BR]=Ferramenta para exportar imagens para o Facebook
Comment[ru]=Инструмент для экспорта в социальную сеть Facebook
Comment[sk]=Nástroj na export obrázkov do vzdialenej webovej služby Facebook
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Facebook
Comment[sv]=Ett verktyg för att exportera bilder till en Facebook webbtjänst
Comment[tr]=Resimleri uzak bir Facebook web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень до віддаленої служби Facebook
Comment[x-test]=xxA tool to export images to a remote Facebook web servicexx
Comment[zh_CN]=一个将图像导出到远程 Facebook 网络服务的工具
Comment[zh_TW]=匯出圖片到遠端 Facebook 網路服務的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_facebook
Icon=kipi-facebook
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Luka Renko, lure at kubuntu dot org
